You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@poi.apache.org by se...@apache.org on 2011/09/21 11:48:16 UTC

svn commit: r1173548 - in /poi/trunk/src: scratchpad/src/org/apache/poi/hwpf/model/types/STDAbstractType.java scratchpad/src/org/apache/poi/hwpf/model/types/StdfBaseAbstractType.java types/definitions/StdfBase_type.xml types/definitions/std_type.xml

Author: sergey
Date: Wed Sep 21 09:48:16 2011
New Revision: 1173548

URL: http://svn.apache.org/viewvc?rev=1173548&view=rev
Log:
rename STD to StdfBase

Added:
    poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/StdfBaseAbstractType.java
      - copied, changed from r1173545, poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/STDAbstractType.java
    poi/trunk/src/types/definitions/StdfBase_type.xml
      - copied, changed from r1173545, poi/trunk/src/types/definitions/std_type.xml
Removed:
    poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/STDAbstractType.java
    poi/trunk/src/types/definitions/std_type.xml

Copied: poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/StdfBaseAbstractType.java (from r1173545, poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/STDAbstractType.java)
URL: http://svn.apache.org/viewvc/poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/StdfBaseAbstractType.java?p2=poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/StdfBaseAbstractType.java&p1=poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/STDAbstractType.java&r1=1173545&r2=1173548&rev=1173548&view=diff
==============================================================================
--- poi/trunk/src/types/definitions/std_type.xml (original)
+++ poi/trunk/src/types/definitions/StdfBase_type.xml Wed Sep 21 09:48:16 2011
@@ -17,10 +17,10 @@
     limitations under the License.
     ====================================================================
 -->
-<record fromfile="true" name="STD" package="org.apache.poi.hwpf.model.types">
+<record fromfile="true" name="StdfBase" package="org.apache.poi.hwpf.model.types">
     <suffix>AbstractType</suffix>
-    <description>Each individual style description is stored in an STD structure. &lt;p&gt;Class and
-        fields descriptions are quoted from Microsoft Office Word 97-2007 Binary File Format and
+    <description>The StdfBase structure specifies general information about a style. &lt;p&gt;Class
+        and fields descriptions are quoted from Microsoft Office Word 97-2007 Binary File Format and
         [MS-DOC] - v20110608 Word (.doc) Binary File Format
     </description>
     <author>Sergey Vladimirov; according to Microsoft Office Word 97-2007 Binary File Format
@@ -45,21 +45,33 @@
             <bit number="1" mask="0x000F" name="cupx" description="number of UPXs (and UPEs)"/>
             <bit number="2" mask="0xFFF0" name="istdNext" description="next style"/>
         </field>
-        <field type="int" size="2" name="bchUpe" description="An unsigned integer that specifies the size, in bytes, of std in LPStd. This value MUST be equal to cbStd in LPStd"/>
-        <field type="short" size="2" name="grfstd" description="A GRFSTD that specifies miscellaneous style properties">
+        <field type="int" size="2" name="bchUpe"
+            description="An unsigned integer that specifies the size, in bytes, of std in LPStd. This value MUST be equal to cbStd in LPStd"/>
+        <field type="short" size="2" name="grfstd"
+            description="A GRFSTD that specifies miscellaneous style properties">
             <bit number="1" mask="0x0001" name="fAutoRedef" description="number of UPXs (and UPEs)"/>
-            <bit number="2" mask="0x0002" name="fHidden" description="Specifies whether this style is not shown in the application UI"/>
-            <bit number="3" mask="0x0004" name="f97LidsSet" description="Specifies whether sprmCRgLid0_80 and sprmCRgLid1_80 were applied, as appropriate, to this paragraph or character style for compatibility with applications that do not support sprmCRgLid0, sprmCRgLid1, and sprmCFNoProof"/>
-            <bit number="4" mask="0x0008" name="fCopyLang" description="If f97LidsSet is 1, this value specifies whether the applied compatibility sprmCRgLid0_80 or sprmCRgLid1_80 specified an actual language or a special LID value (0x0400) signifying that no proofing is needed for the text. This MUST be ignored if f97LidsSet is 0"/>
-            <bit number="5" mask="0x0010" name="fPersonalCompose" description="Specifies whether this character style can be used to automatically format the new message text in a new e-mail"/>
-            <bit number="6" mask="0x0020" name="fPersonalReply" description="Specifies whether this character style can be used to automatically format the new message text when replying to an e-mail"/>
-            <bit number="7" mask="0x0040" name="fPersonal" description="Specifies whether this character style was applied to format all message text from one or more users in an e-mail"/>
+            <bit number="2" mask="0x0002" name="fHidden"
+                description="Specifies whether this style is not shown in the application UI"/>
+            <bit number="3" mask="0x0004" name="f97LidsSet"
+                description="Specifies whether sprmCRgLid0_80 and sprmCRgLid1_80 were applied, as appropriate, to this paragraph or character style for compatibility with applications that do not support sprmCRgLid0, sprmCRgLid1, and sprmCFNoProof"/>
+            <bit number="4" mask="0x0008" name="fCopyLang"
+                description="If f97LidsSet is 1, this value specifies whether the applied compatibility sprmCRgLid0_80 or sprmCRgLid1_80 specified an actual language or a special LID value (0x0400) signifying that no proofing is needed for the text. This MUST be ignored if f97LidsSet is 0"/>
+            <bit number="5" mask="0x0010" name="fPersonalCompose"
+                description="Specifies whether this character style can be used to automatically format the new message text in a new e-mail"/>
+            <bit number="6" mask="0x0020" name="fPersonalReply"
+                description="Specifies whether this character style can be used to automatically format the new message text when replying to an e-mail"/>
+            <bit number="7" mask="0x0040" name="fPersonal"
+                description="Specifies whether this character style was applied to format all message text from one or more users in an e-mail"/>
             <bit number="8" mask="0x0080" name="fNoHtmlExport" description="This value MUST be 0 and MUST be ignored"/>
-            <bit number="9" mask="0x0100" name="fSemiHidden" description="Specifies whether this style is not shown in the simplified main styles UI of the application"/>
-            <bit number="10" mask="0x0200" name="fLocked" description="Specifies whether this style is prevented from being applied by using the application UI"/>
+            <bit number="9" mask="0x0100" name="fSemiHidden"
+                description="Specifies whether this style is not shown in the simplified main styles UI of the application"/>
+            <bit number="10" mask="0x0200" name="fLocked"
+                description="Specifies whether this style is prevented from being applied by using the application UI"/>
             <bit number="11" mask="0x0400" name="fInternalUse" description="This bit is undefined and MUST be ignored"/>
-            <bit number="12" mask="0x0800" name="fUnhideWhenUsed" description="Specifies whether the fSemiHidden property is to be set to 0 when this style is used"/>
-            <bit number="13" mask="0x1000" name="fQFormat" description="Specifies whether this style is shown in the Ribbon Style gallery"/>
+            <bit number="12" mask="0x0800" name="fUnhideWhenUsed"
+                description="Specifies whether the fSemiHidden property is to be set to 0 when this style is used"/>
+            <bit number="13" mask="0x1000" name="fQFormat"
+                description="Specifies whether this style is shown in the Ribbon Style gallery"/>
             <bit number="14" mask="0xE000" name="fReserved" description="This value MUST be 0 and MUST be ignored"/>
         </field>
     </fields>



---------------------------------------------------------------------
To unsubscribe, e-mail: commits-unsubscribe@poi.apache.org
For additional commands, e-mail: commits-help@poi.apache.org
--- poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/STDAbstractType.java (original)
+++ poi/trunk/src/scratchpad/src/org/apache/poi/hwpf/model/types/StdfBaseAbstractType.java Wed Sep 21 09:48:16 2011
@@ -22,8 +22,8 @@ import org.apache.poi.util.Internal;
 import org.apache.poi.util.LittleEndian;
 
 /**
- * Each individual style description is stored in an STD structure. <p>Class and
-        fields descriptions are quoted from Microsoft Office Word 97-2007 Binary File Format and
+ * The StdfBase structure specifies general information about a style. <p>Class
+        and fields descriptions are quoted from Microsoft Office Word 97-2007 Binary File Format and
         [MS-DOC] - v20110608 Word (.doc) Binary File Format
     
  * <p>
@@ -38,7 +38,7 @@ import org.apache.poi.util.LittleEndian;
     
  */
 @Internal
-public abstract class STDAbstractType
+public abstract class StdfBaseAbstractType
 {
 
     protected short field_1_info1;
@@ -70,7 +70,7 @@ public abstract class STDAbstractType
     /**/private static final BitField fQFormat = new BitField(0x1000);
     /**/private static final BitField fReserved = new BitField(0xE000);
 
-    protected STDAbstractType()
+    protected StdfBaseAbstractType()
     {
     }
 
@@ -103,7 +103,7 @@ public abstract class STDAbstractType
     public String toString()
     {
         StringBuilder builder = new StringBuilder();
-        builder.append("[STD]\n");
+        builder.append("[StdfBase]\n");
         builder.append("    .info1                = ");
         builder.append(" (").append(getInfo1()).append(" )\n");
         builder.append("         .sti                      = ").append(getSti()).append('\n');
@@ -138,12 +138,12 @@ public abstract class STDAbstractType
         builder.append("         .fQFormat                 = ").append(isFQFormat()).append('\n');
         builder.append("         .fReserved                = ").append(getFReserved()).append('\n');
 
-        builder.append("[/STD]\n");
+        builder.append("[/StdfBase]\n");
         return builder.toString();
     }
 
     /**
      * Get the info1 field for the STD record.
      */
     @Internal
     public short getInfo1()
@@ -152,7 +152,7 @@ public abstract class STDAbstractType
     }
 
     /**
      * Set the info1 field for the STD record.
      */
     @Internal
     public void setInfo1( short field_1_info1 )
@@ -161,7 +161,7 @@ public abstract class STDAbstractType
     }
 
     /**
      * Get the info2 field for the STD record.
      */
     @Internal
     public short getInfo2()
@@ -170,7 +170,7 @@ public abstract class STDAbstractType
     }
 
     /**
      * Set the info2 field for the STD record.
      */
     @Internal
     public void setInfo2( short field_2_info2 )
@@ -179,7 +179,7 @@ public abstract class STDAbstractType
     }
 
     /**
      * Get the info3 field for the STD record.
      */
     @Internal
     public short getInfo3()
@@ -188,7 +188,7 @@ public abstract class STDAbstractType
     }
 
     /**
      * Set the info3 field for the STD record.
      */
     @Internal
     public void setInfo3( short field_3_info3 )
@@ -138,12 +138,12 @@ public abstract class STDAbstractType
 
     /**
-     * Get the info1 field for the STD record.
+     * Get the info1 field for the StdfBase record.
      */
     @Internal
@@ -152,7 +152,7 @@ public abstract class STDAbstractType
 
     /**
-     * Set the info1 field for the STD record.
+     * Set the info1 field for the StdfBase record.
      */
     @Internal
@@ -161,7 +161,7 @@ public abstract class STDAbstractType
 
     /**
-     * Get the info2 field for the STD record.
+     * Get the info2 field for the StdfBase record.
      */
     @Internal
@@ -170,7 +170,7 @@ public abstract class STDAbstractType
 
     /**
-     * Set the info2 field for the STD record.
+     * Set the info2 field for the StdfBase record.
      */
     @Internal
@@ -179,7 +179,7 @@ public abstract class STDAbstractType
 
     /**
-     * Get the info3 field for the STD record.
+     * Get the info3 field for the StdfBase record.
      */
     @Internal
@@ -188,7 +188,7 @@ public abstract class STDAbstractType
 
     /**
-     * Set the info3 field for the STD record.
+     * Set the info3 field for the StdfBase record.
      */
     @Internal

Copied: poi/trunk/src/types/definitions/StdfBase_type.xml (from r1173545, poi/trunk/src/types/definitions/std_type.xml)
URL: http://svn.apache.org/viewvc/poi/trunk/src/types/definitions/StdfBase_type.xml?p2=poi/trunk/src/types/definitions/StdfBase_type.xml&p1=poi/trunk/src/types/definitions/std_type.xml&r1=1173545&r2=1173548&rev=1173548&view=diff
==============================================================================